import filecmp
from os import path

from delivery.deliverer import LocalDestination


def test_local_delivery_add_file(tmpdir):
    """Ensure that local delivery does something"""
    file_name = "test.txt"
    temp_file = tmpdir.mkdir("prior").join(file_name) # place a file into the source
    temp_file.write_text("content", encoding=None) # write something into that file
    dest_dir = tmpdir.mkdir("after") # create a destination
    local_dest = LocalDestination(None, dest_dir)
    local_dest.add_file(temp_file, str(dest_dir / file_name))
    # see if the source file eneded up in the destination
    assert path.exists(dest_dir / file_name)
    # see if the content of the file is intact
    assert (dest_dir / file_name).read_text(encoding=None) == "content"

def test_local_delivery_add_directory(tmpdir):
    """Ensure that local delivery does something"""
    source_dir = tmpdir.mkdir("prior") # create a source
    temp_file = source_dir.join("test.txt") # add a file to the source dir
    temp_file.write_text("content", encoding=None) # add some content to the file
    temp_file2 = source_dir.join("test2.txt") # make another file in source
    temp_file2.write_text("more content", encoding=None) # add some content to the second file
    local_dest = LocalDestination(None, str(tmpdir))
    local_dest.add_directory(source_dir, "after") # destination is defined here
    compare_dirs = filecmp.dircmp(source_dir, tmpdir / "after")
    # see if the destination got all the files from source
    assert len(compare_dirs.left_only) == 0 and len(compare_dirs.right_only) == 0 and \
           len(compare_dirs.funny_files) == 0
