import {Injectable} from "@angular/core";
import {HttpClient} from "@angular/common/http";
import {environment} from "../../../environments/environment";
import {Observable} from "rxjs";
import {CapabilityRequest} from "../model/capability-request";
import {CapabilityExecution} from "../model/capability-execution";

@Injectable({
  providedIn: "root",
})
export class CapabilityLauncherService {
  private endpoint = "capability/request";

  constructor(private httpClient: HttpClient) {}

  /**
   * Create capability request and send it to capability service
   * @param: capabilityName  Name of capability to create request for
   * @param: args  Arguments for capability execution
   */
  createRequest(
    capabilityName: string,
    args: string
  ): Observable<CapabilityRequest> {
    const url = environment.workspacesUrl + this.endpoint;
    const params = JSON.stringify({ capability: capabilityName, args: args });
    return this.httpClient.post<CapabilityRequest>(url, params);
  }

  /**
   * Submit capability request
   * @param: requestId  ID of capability request to submit
   */
  submit(requestId: string): Observable<CapabilityExecution> {
    const url = `${environment.workspacesUrl}${this.endpoint}/${requestId}/submit`;
    return this.httpClient.post<CapabilityExecution>(url, null);
  }
}
